==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/connectionmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ConnectionManager</name>
    <message>
        <source>Connection Manager</source>
        <translation>Verbindungsmanager</translation>
    </message>
    <message>
        <source>Allows to use different types of connections to a Jabber server</source>
        <translation>Erlaubt das Benutzen von verschiedenen Verbindungsarten zu einem Jabberserver</translation>
    </message>
    <message>
        <source>&lt;No Proxy&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>New Proxy</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConnectionOptionsWidgetClass</name>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>Connection:</source>
        <translation>Verbindung:</translation>
    </message>
</context>
<context>
    <name>EditProxyDialog</name>
    <message>
        <source>HTTP Proxy</source>
        <translation></translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation></translation>
    </message>
    <message>
        <source>New Proxy</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EditProxyDialogClass</name>
    <message>
        <source>Proxy Manager</source>
        <translation></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <source>User:</source>
        <translation></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation></translation>
    </message>
    <message>
        <source>Default Proxy:</source>
        <translation></translation>
    </message>
    <message>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProxySettingsWidget</name>
    <message>
        <source>&lt;Default Proxy&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProxySettingsWidgetClass</name>
    <message>
        <source>Proxy:</source>
        <translation></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/connectionmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ConnectionManager</name>
    <message>
        <source>Connection Manager</source>
        <translation>Verbindungsmanager</translation>
    </message>
    <message>
        <source>Allows to use different types of connections to a Jabber server</source>
        <translation>Erlaubt das Benutzen verschiedener Verbindungsarten zu einem Jabber-Server</translation>
    </message>
    <message>
        <source>&lt;No Proxy&gt;</source>
        <translation>&lt;Kein Proxy&gt;</translation>
    </message>
    <message>
        <source>New Proxy</source>
        <translation>Neuer Proxy</translation>
    </message>
</context>
<context>
    <name>ConnectionOptionsWidgetClass</name>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>Connection:</source>
        <translation>Verbindung:</translation>
    </message>
</context>
<context>
    <name>EditProxyDialog</name>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <source>New Proxy</source>
        <translation>Neuer Proxy</translation>
    </message>
</context>
<context>
    <name>EditProxyDialogClass</name>
    <message>
        <source>Proxy Manager</source>
        <translation>Proxy Manager</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Benutzer:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Default Proxy:</source>
        <translation>Standard Proxy:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>ProxySettingsWidget</name>
    <message>
        <source>&lt;Default Proxy&gt;</source>
        <translation>&lt;Standard Proxy&gt;</translation>
    </message>
</context>
<context>
    <name>ProxySettingsWidgetClass</name>
    <message>
        <source>Proxy:</source>
        <translation>Proxy:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
</context>
</TS>
